Documentation
¶
Overview ¶
Package schemas locates and validates the versioned schema documents kept in the repository's document-only versions directory.
Index ¶
- func BrowserAuthenticationCallSupplementSchema(profile string) ([]byte, error)
- func BrowserAuthenticationProfileSchema(profile string) ([]byte, error)
- func BrowserRegistrationCallSupplementSchema(profile string) ([]byte, error)
- func BrowserRegistrationProfileSchema(profile string) ([]byte, error)
- func BrowserSourceProfileSchema(profile string) ([]byte, error)
- func PathForBrowserAuthenticationCallSupplement(anchorDir, profile string) string
- func PathForBrowserAuthenticationProfile(anchorDir, profile string) string
- func PathForBrowserRegistrationCallSupplement(anchorDir, profile string) string
- func PathForBrowserRegistrationProfile(anchorDir, profile string) string
- func PathForBrowserSourceProfile(anchorDir, profile string) string
- func PathForRuntimeSupplement(anchorDir, profile string) string
- func PathForVersion(anchorDir, version string) string
- func ValidateBrowserAuthenticationCallSupplement(data []byte) error
- func ValidateBrowserAuthenticationCallSupplementForProfile(data []byte, profile string) error
- func ValidateBrowserAuthenticationProfile(data []byte) error
- func ValidateBrowserRegistrationCallSupplement(data []byte) error
- func ValidateBrowserRegistrationProfile(data []byte) error
- func ValidateBrowserSourceProfile(data []byte) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BrowserAuthenticationCallSupplementSchema ¶
BrowserAuthenticationCallSupplementSchema returns an independent copy of the embedded browser-authentication-call JSON Schema selected by profile. An empty profile selects uws.browser-authentication-call.1.1.
func BrowserAuthenticationProfileSchema ¶
BrowserAuthenticationProfileSchema returns an independent copy of the embedded browser-authentication JSON Schema selected by profile. An empty profile selects uws.browser-authentication.1.1.
func BrowserRegistrationCallSupplementSchema ¶
BrowserRegistrationCallSupplementSchema returns an independent copy of the embedded browser-registration-call JSON Schema. An empty profile selects uws.browser-registration-call.1.0.
func BrowserRegistrationProfileSchema ¶
BrowserRegistrationProfileSchema returns an independent copy of the embedded browser-registration JSON Schema. An empty profile selects uws.browser-registration.1.0.
func BrowserSourceProfileSchema ¶
BrowserSourceProfileSchema returns an independent copy of the embedded browser-profile JSON Schema selected by profile. An empty profile selects the current uws.browser.1.7 contract.
func PathForBrowserAuthenticationCallSupplement ¶
PathForBrowserAuthenticationCallSupplement returns the best local schema path for the browser-authentication-call operation supplement.
func PathForBrowserAuthenticationProfile ¶
PathForBrowserAuthenticationProfile returns the best local schema path for a portable browser-authentication recipe.
func PathForBrowserRegistrationCallSupplement ¶
PathForBrowserRegistrationCallSupplement returns the best local schema path for the browser-registration-call operation supplement.
func PathForBrowserRegistrationProfile ¶
PathForBrowserRegistrationProfile returns the best local schema path for a portable browser account-registration recipe.
func PathForBrowserSourceProfile ¶
PathForBrowserSourceProfile returns the best local schema path for a browser source profile.
func PathForRuntimeSupplement ¶
PathForRuntimeSupplement returns the best local schema path for a runtime supplement profile.
func PathForVersion ¶
PathForVersion returns the best local schema path for a UWS document version.
func ValidateBrowserAuthenticationCallSupplement ¶
ValidateBrowserAuthenticationCallSupplement validates the extension payload envelope used by an explicit authentication operation.
func ValidateBrowserAuthenticationCallSupplementForProfile ¶
ValidateBrowserAuthenticationCallSupplementForProfile validates the call envelope against the explicitly selected supplement version. Call envelopes have no document discriminator, so version selection cannot be inferred.
func ValidateBrowserAuthenticationProfile ¶
ValidateBrowserAuthenticationProfile validates one portable, secret-free browser authentication recipe. In addition to JSON Schema validation it enforces exact safe origins and the 1 MiB document bound.
func ValidateBrowserRegistrationCallSupplement ¶
ValidateBrowserRegistrationCallSupplement validates the extension envelope used by one explicitly approved registration mutation.
func ValidateBrowserRegistrationProfile ¶
ValidateBrowserRegistrationProfile validates one portable, secret-free account-registration recipe. It enforces exact safe origins, symbolic slot references, exactly one account-creation submit, explicit confirmation, and consistency between human checkpoints and declared effects.
func ValidateBrowserSourceProfile ¶
ValidateBrowserSourceProfile validates one JSON or YAML browser-profile document against the embedded schema selected by its profile discriminator. Freshness, review evidence, registry lifecycle, sessions, and execution policy remain downstream responsibilities.
Types ¶
This section is empty.